@@ -19,6 +19,8 @@ We should work to replace this with components from the keras-nlp library.
 import tensorflow as tf
 from tensorflow import keras
 
+import keras_nlp
+
 
 def make_attention_mask(inputs, mask):
     """Make a 3D attention mask from a 2D input mask.
@@ -331,72 +333,6 @@ class TransformerEncoderBlock(keras.layers.Layer):
         return self._output_layer_norm(layer_output + attention_output)
 
 
-class PositionEmbedding(keras.layers.Layer):
-    """Creates a positional embedding.
-
-    Example:
-    ```python
-    position_embedding = PositionEmbedding(max_length=100)
-    inputs = keras.Input((100, 32), dtype=tf.float32)
-    outputs = position_embedding(inputs)
-    ```
-
-
-    Args:
-        max_length: The maximum size of the dynamic sequence.
-        initializer: The initializer to use for the embedding weights. Defaults
-            to "glorot_uniform".
-        seq_axis: The axis of the input tensor where we add the embeddings.
-
-    Reference: This layer creates a positional embedding as described in
-    [BERT: Pre-training of Deep Bidirectional Transformers for Language
-    Understanding](https://arxiv.org/abs/1810.04805).
-    """
-
-    def __init__(
-        self, max_length, initializer="glorot_uniform", seq_axis=1, **kwargs
-    ):
-
-        super().__init__(**kwargs)
-        if max_length is None:
-            raise ValueError("`max_length` must be an Integer, not `None`.")
-        self._max_length = max_length
-        self._initializer = keras.initializers.get(initializer)
-        self._seq_axis = seq_axis
-
-    def get_config(self):
-        config = {
-            "max_length": self._max_length,
-            "initializer": keras.initializers.serialize(self._initializer),
-            "seq_axis": self._seq_axis,
-        }
-        base_config = super().get_config()
-        return dict(list(base_config.items()) + list(config.items()))
-
-    def build(self, input_shape):
-        dimension_list = input_shape.as_list()
-        width = dimension_list[-1]
-        weight_sequence_length = self._max_length
-
-        self._position_embeddings = self.add_weight(
-            "embeddings",
-            shape=[weight_sequence_length, width],
-            initializer=self._initializer,
-        )
-
-        super().build(input_shape)
-
-    def call(self, inputs):
-        input_shape = tf.shape(inputs)
-        actual_seq_len = input_shape[self._seq_axis]
-        position_embeddings = self._position_embeddings[:actual_seq_len, :]
-        new_shape = [1 for _ in inputs.get_shape().as_list()]
-        new_shape[self._seq_axis] = actual_seq_len
-        new_shape[-1] = position_embeddings.get_shape().as_list()[-1]
-        position_embeddings = tf.reshape(position_embeddings, new_shape)
-        return tf.broadcast_to(position_embeddings, input_shape)
-
-
 # TODO(mattdangerw): This class is needed for TPU friendly embeddings, we should
 # remove it entirely and fix tf.keras.layers.Embedding as needed.
 class OnDeviceEmbedding(keras.layers.Layer):
@@ -546,7 +482,7 @@ class BertModel(keras.Model):
             name="word_embeddings",
         )
 
-        self._position_embedding_layer = PositionEmbedding(
+        self._position_embedding_layer = keras_nlp.layers.PositionEmbedding(
             initializer=initializer,
             max_length=max_sequence_length,
             name="position_embedding",
